#ifndef _myAlg_H
#define _myAlg_H 1

#include "IAlgBase.h"

#include <vector>
#include <utility>

#include "Plane.h"
#include "Track.h"
#include "TRandom.h" 
#include "TrackStore.h"


class TFile;
class TF1;
class TH1F;
class TH2F;

class IMilleTool;

class myAlg: public IAlgBase {

 public:

  /** constructer */
  myAlg();

  /** destructer */
  virtual ~myAlg();

  virtual bool initialize(const jobParams& tparams);

  virtual bool execute();

  virtual bool finalize();


protected:

  /** parameters for this job */	 
   jobParams params() const;

  /** root file */
  TFile* rootFile() const; 

  IMilleTool* m_align;

 private:

  Planes m_idealGeometry;  // The detector (a vector of planes)
  TrackStore *my_tracks;
  Tracks input_tracks;

  double offset(const double sizeOff) const;

  std::vector<double> m_offsetX;  // X translation
  std::vector<double> m_offsetY;  // Y translation
  std::vector<double> m_offsetZ;  // Z translation

  std::vector<double> m_offsetA;  // Rotation around X
  std::vector<double> m_offsetB;  // Rotation around Y
  std::vector<double> m_offsetC;  // Rotation around Z

 
  jobParams m_params;
  TFile* m_rootFile;
  TF1* m_GaussGenerator;

  // histos
  std::vector<TH1F*> m_mis_bef;
  std::vector<TH1F*> m_mis_aft;
  std::vector<TH1F*> m_pullHistos;

};

inline jobParams myAlg::params() const{
  return m_params;
} 


inline TFile* myAlg::rootFile() const{
  return m_rootFile;
}

#include "TF1.h"

inline double myAlg::offset(const double sizeOff) const{
  return (m_GaussGenerator->GetRandom()*sizeOff);
}

#endif
